.. _api:

API documentation
=================

.. toctree::
   :maxdepth: 2

   adminui
   adminui.utils
   extensions
   integration/fluent_contents
   models
   models.navigation
   templatetags/appurl_tags
   templatetags/fluent_pages_tags
   sitemaps
   urlresolvers
   views


Deprecated modules
------------------

.. toctree::
   :maxdepth: 2

   pagetypes.fluentpage.admin
   pagetypes.fluentpage.models

..
    Kept out of public API:
    - forms
    - utils.*
